@@ -1,4 +1,4 @@
-# Copyright 2018 QuantRocket - All Rights Reserved
+# Copyright 2017-2022 QuantRocket - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,8 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import argparse
-from quantrocket.cli.utils.parse import dict_str
+from quantrocket.cli.utils.parse import dict_str, HelpFormatter
 
 def add_subparser(subparsers):
     _parser = subparsers.add_parser("blotter", description="QuantRocket blotter CLI", help="Place orders and track executions")
@@ -30,21 +29,27 @@ Examples:
 
 Place orders from a CSV file.
 
+.. code-block:: bash
+
     quantrocket blotter order -f orders.csv
 
 Place orders from a JSON file.
 
+.. code-block:: bash
+
     quantrocket blotter order -f orders.json
 
 Place an order by specifying the order parameters on the command line:
 
+.. code-block:: bash
+
     quantrocket blotter order --params Sid:FIBBG123456 Action:BUY Exchange:SMART TotalQuantity:100 OrderType:MKT Tif:Day Account:DU12345 OrderRef:my-strategy
     """
     parser = _subparsers.add_parser(
         "order",
         help="place one or more orders",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     source_group = parser.add_mutually_exclusive_group()
     source_group.add_argument(
         "-f", "--infile",
@@ -68,25 +73,33 @@ Examples:
 
 Cancel orders by order ID:
 
+.. code-block:: bash
+
     quantrocket blotter cancel -d 6002:45 6001:46
 
 Cancel orders by sid:
 
+.. code-block:: bash
+
     quantrocket blotter cancel -i FIBBG123456
 
 Cancel orders by order ref:
 
+.. code-block:: bash
+
     quantrocket blotter cancel --order-refs my-strategy
 
 Cancel all open orders:
 
+.. code-block:: bash
+
     quantrocket blotter cancel --all
     """
     parser = _subparsers.add_parser(
         "cancel",
         help="cancel one or more orders by order ID, sid, or order ref",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     parser.add_argument(
         "-d", "--order-ids",
         metavar="ORDER_ID",
@@ -122,29 +135,39 @@ Examples:
 
 Download order status by order ID and save to file:
 
+.. code-block:: bash
+
     quantrocket blotter status -d 6002:45 6001:46 -o statuses.csv
 
 Download order status for all open orders and display in terminal:
 
+.. code-block:: bash
+
     quantrocket blotter status --open | csvlook
 
 Download order status with extra fields and display as YAML:
 
+.. code-block:: bash
+
     quantrocket blotter status --open --fields Exchange LmtPrice --json | json2yaml
 
 Download order status of open orders by sid:
 
+.. code-block:: bash
+
     quantrocket blotter status -i FIBBG123456 --open
 
 Download order status of open orders by order ref:
 
+.. code-block:: bash
+
     quantrocket blotter status --order-refs my-strategy --open
     """
     parser = _subparsers.add_parser(
         "status",
         help="download order statuses",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     filters = parser.add_argument_group("filtering options")
     filters.add_argument(
         "-d", "--order-ids",
@@ -214,25 +237,33 @@ Examples:
 
 Query current positions:
 
+.. code-block:: bash
+
     quantrocket blotter positions
 
 Save current positions to CSV file:
 
+.. code-block:: bash
+
     quantrocket blotter positions --outfile positions.csv
 
 Query positions for a single order ref:
 
+.. code-block:: bash
+
     quantrocket blotter positions --order-refs my-strategy
 
 Query positions using broker view:
 
+.. code-block:: bash
+
     quantrocket blotter positions --broker
     """
     parser = _subparsers.add_parser(
         "positions",
         help="query current positions",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     filters = parser.add_argument_group("filtering options")
     filters.add_argument(
         "-i", "--sids",
@@ -289,22 +320,28 @@ Examples:
 
 Generate MKT orders to close positions for a particular strategy:
 
+.. code-block:: bash
+
     quantrocket blotter close --order-refs my-strategy --params OrderType:MKT Tif:DAY Exchange:SMART
 
 Generate orders and also place them:
 
+.. code-block:: bash
+
     quantrocket blotter close -r my-strategy -p OrderType:MKT Tif:DAY Exchange:SMART | quantrocket blotter order -f -
 
 After receiving 23.50 per share in a tender offer for a position, record the execution
 in the blotter in order to mark the position as closed:
 
+.. code-block:: bash
+
     quantrocket blotter close --sids FIBBG123456 --params Price:23.50 | quantrocket blotter record -f -
     """
     parser = _subparsers.add_parser(
         "close",
         help="generate orders to close positions",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     filters = parser.add_argument_group("filtering options")
     filters.add_argument(
         "-i", "--sids",
@@ -349,13 +386,15 @@ Examples:
 
 Get a CSV of all executions:
 
+.. code-block:: bash
+
     quantrocket blotter executions -o executions.csv
     """
     parser = _subparsers.add_parser(
         "executions",
         help="query executions from the executions database",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     filters = parser.add_argument_group("filtering options")
     filters.add_argument(
         "-i", "--sids",
@@ -405,14 +444,20 @@ Examples:
 After receiving 23.50 per share in a tender offer for a position, record the execution
 in the blotter in order to mark the position as closed:
 
+.. code-block:: bash
+
     quantrocket blotter close --sids FIBBG123456 --params Price:23.50 | quantrocket blotter record -f -
 
 Record executions from a CSV file:
 
+.. code-block:: bash
+
     quantrocket blotter record -f executions.csv
 
 Record an execution by specifying the parameters on the command line:
 
+.. code-block:: bash
+
     quantrocket blotter record --params Sid:FIBBG123456 Action:BUY TotalQuantity:100 Account:DU12345 OrderRef:my-strategy Price:23.50
 
 The required params are:
@@ -434,7 +479,7 @@ Optional params (rarely needed):
         "record",
         help="record executions that happened outside of QuantRocket's knowledge",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     source_group = parser.add_mutually_exclusive_group()
     source_group.add_argument(
         "-f", "--infile",
@@ -467,17 +512,21 @@ Examples:
 
 Record a 2-for-1 split:
 
+.. code-block:: bash
+
     quantrocket blotter split --sid FIBBG12345 --old-shares 1 --new-shares 2
 
 Record a 1-for-10 reverse split:
 
+.. code-block:: bash
+
     quantrocket blotter split --sid FIBBG98765 --old-shares 10 --new-shares 1
     """
     parser = _subparsers.add_parser(
         "split",
         help="apply a stock split to an open position",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     parser.add_argument(
         "-i", "--sid",
         metavar="SID",
@@ -508,21 +557,27 @@ Examples:
 
 Get a Moonchart PDF of all trading performance PNL:
 
+.. code-block:: bash
+
     quantrocket blotter pnl -o pnl.pdf --pdf
 
 Get a PDF for a single account and order ref, broken down by sid:
 
+.. code-block:: bash
+
     quantrocket blotter pnl --accounts U12345 --order-refs mystrategy1 --details --pdf -o pnl_details.pdf
 
 Get a CSV of performance results for a particular date range:
 
+.. code-block:: bash
+
     quantrocket blotter pnl -s 2018-03-01 -e 2018-06-30 -o pnl_2018Q2.csv
     """
     parser = _subparsers.add_parser(
         "pnl",
         help="query trading performance and return a PDF tearsheet or CSV of results",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     filters = parser.add_argument_group("filtering options")
     filters.add_argument(
         "-i", "--sids",
