@@ -1,4 +1,4 @@
-# Copyright 2017 QuantRocket - All Rights Reserved
+# Copyright 2017-2022 QuantRocket - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,8 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import argparse
-from quantrocket.cli.utils.parse import dict_str
+from quantrocket.cli.utils.parse import dict_str, list_or_int_or_float_or_str, HelpFormatter
 
 def add_subparser(subparsers):
     _parser = subparsers.add_parser("zipline", description="QuantRocket CLI for Zipline", help="Backtest and trade Zipline strategies")
@@ -30,25 +29,33 @@ Examples:
 
 Create a minute data bundle for all US stocks:
 
+.. code-block:: bash
+
     quantrocket zipline create-usstock-bundle usstock-1min
 
 Create a bundle for daily data only:
 
+.. code-block:: bash
+
     quantrocket zipline create-usstock-bundle usstock-1d --data-frequency daily
 
 Create a minute data bundle based on a universe:
 
+.. code-block:: bash
+
     quantrocket zipline create-usstock-bundle usstock-tech-1min --universes us-tech
 
 Create a minute data bundle of free sample data:
 
+.. code-block:: bash
+
     quantrocket zipline create-usstock-bundle usstock-free-1min --free
     """
     parser = _subparsers.add_parser(
         "create-usstock-bundle",
         help="create a Zipline bundle for US stocks",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     parser.add_argument(
         "code",
         metavar="CODE",
@@ -72,6 +79,54 @@ Create a minute data bundle of free sample data:
         "only daily data. Default is minute data. Possible choices: %(choices)s")
     parser.set_defaults(func="quantrocket.zipline._cli_create_usstock_bundle")
 
+    examples = """
+Create a Zipline bundle of daily data for Sharadar stocks and/or ETFs.
+
+This command defines the bundle parameters but does not ingest the actual
+data. To ingest the data, see `quantrocket zipline ingest`.
+
+Examples:
+
+Create a bundle for all Sharadar stocks and ETFs:
+
+.. code-block:: bash
+
+    quantrocket zipline create-sharadar-bundle sharadar-1d
+
+Create a bundle for ETFs only:
+
+.. code-block:: bash
+
+    quantrocket zipline create-sharadar-bundle sharadar-etf-1d --sec-types ETF
+
+Create a bundle of free sample data:
+
+.. code-block:: bash
+
+    quantrocket zipline create-sharadar-bundle sharadar-free-1d --free
+    """
+    parser = _subparsers.add_parser(
+        "create-sharadar-bundle",
+        help="create a Zipline bundle of daily data for Sharadar stocks and/or ETFs",
+        epilog=examples,
+        formatter_class=HelpFormatter)
+    parser.add_argument(
+        "code",
+        metavar="CODE",
+        help="the code to assign to the bundle (lowercase alphanumerics and hyphens only)")
+    parser.add_argument(
+        "-t", "--sec-types",
+        nargs="*",
+        metavar="SEC_TYPE",
+        choices=["STK", "ETF"],
+        help="limit to these security types. Possible choices: %(choices)s. "
+        "Default is to include both stocks and ETFs.")
+    parser.add_argument(
+        "--free",
+        action="store_true",
+        help="limit to free sample data")
+    parser.set_defaults(func="quantrocket.zipline._cli_create_sharadar_bundle")
+
     examples = """
 Create a Zipline bundle from a history database or real-time aggregate
 database.
@@ -86,23 +141,29 @@ Examples:
 Create a bundle from a history database called "es-fut-1min" and name
 it like the history database:
 
+.. code-block:: bash
+
     quantrocket zipline create-bundle-from-db es-fut-1min --from-db es-fut-1min --calendar us_futures --start-date 2015-01-01
 
 Create a bundle named "usa-stk-1min-2017" for ingesting a single year of US
 1-minute stock data from a history database called "usa-stk-1min":
 
+.. code-block:: bash
+
     quantrocket zipline create-bundle-from-db usa-stk-1min-2017 --from-db usa-stk-1min -s 2017-01-01 -e 2017-12-31 --calendar XNYS
 
 Create a bundle from a real-time aggregate database and specify how to map
 Zipline fields to the database fields:
 
+.. code-block:: bash
+
     quantrocket zipline create-bundle-from-db free-stk-1min --from-db free-stk-tick-1min --calendar XNYS --start-date 2020-06-01 --fields close:LastPriceClose open:LastPriceOpen high:LastPriceHigh low:LastPriceLow volume:VolumeClose
     """
     parser = _subparsers.add_parser(
         "create-bundle-from-db",
         help="create a Zipline bundle from a history database or real-time aggregate database",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     parser.add_argument(
         "code",
         metavar="CODE",
@@ -110,7 +171,12 @@ Zipline fields to the database fields:
     parser.add_argument(
         "-d", "--from-db",
         metavar="CODE",
-        help="the code of a history database or real-time aggregate database to ingest")
+        nargs="+",
+        required=True,
+        help="the code(s) of one or more history databases or real-time aggregate databases "
+        "to ingest. If multiple databases are specified, they must have the same bar "
+        "size and same fields. If a security is present in multiple databases, the first "
+        "database's values will be used.")
     parser.add_argument(
         "-c", "--calendar",
         metavar="NAME",
@@ -164,13 +230,15 @@ Examples:
 
 Ingest data into a bundle called usstock-1min:
 
+.. code-block:: bash
+
     quantrocket zipline ingest usstock-1min
     """
     parser = _subparsers.add_parser(
         "ingest",
         help="ingest data into a previously defined bundle",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     parser.add_argument(
         "code",
         metavar="CODE",
@@ -192,13 +260,15 @@ List available data bundles and whether data has been ingested into them.
 
 Examples:
 
+.. code-block:: bash
+
     quantrocket zipline list-bundles
     """
     parser = _subparsers.add_parser(
         "list-bundles",
         help="list available data bundles and whether data has been ingested into them",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     parser.set_defaults(func="quantrocket.zipline._cli_list_bundles")
 
     examples = """
@@ -208,13 +278,15 @@ Examples:
 
 Return the configuration of a bundle called 'usstock-1min':
 
+.. code-block:: bash
+
     quantrocket zipline config usstock-1min
     """
     parser = _subparsers.add_parser(
         "config",
         help="return the configuration of a bundle",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     parser.add_argument(
         "code",
         metavar="CODE",
@@ -228,13 +300,15 @@ Examples:
 
 Delete a bundle called 'es-fut-1min':
 
+.. code-block:: bash
+
     quantrocket zipline drop-bundle es-fut-1min --confirm-by-typing-bundle-code-again es-fut-1min
     """
     parser = _subparsers.add_parser(
         "drop-bundle",
         help="delete a bundle",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     parser.add_argument(
         "code",
         metavar="CODE",
@@ -258,17 +332,21 @@ Examples:
 
 Set a bundle named usstock-1min as the default:
 
+.. code-block:: bash
+
     quantrocket zipline default-bundle usstock-1min
 
 Show current default bundle:
 
+.. code-block:: bash
+
     quantrocket zipline default-bundle
     """
     parser = _subparsers.add_parser(
         "default-bundle",
         help="set or show the default bundle to use for backtesting and trading",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     parser.add_argument(
         "bundle",
         nargs="?",
@@ -283,13 +361,15 @@ Examples:
 Download a CSV of minute prices since 2015 for a single security from a bundle called
 "usstock-1min":
 
+.. code-block:: bash
+
     quantrocket zipline get usstock-1min --start-date 2015-01-01 -i FIBBG12345 -o minute_prices.csv
     """
     parser = _subparsers.add_parser(
         "get",
         help="query minute or daily data from a Zipline bundle and download to a CSV file",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     parser.add_argument(
         "code",
         metavar="CODE",
@@ -361,13 +441,15 @@ Examples:
 Run a backtest from a strategy file called etf-arb.py and save a CSV file of results,
 logging backtest progress at annual intervals:
 
+.. code-block:: bash
+
     quantrocket zipline backtest etf-arb --bundle arca-etf-eod -s 2010-04-01 -e 2016-02-01 -o results.csv --progress A
     """
     parser = _subparsers.add_parser(
         "backtest",
         help="backtest a Zipline strategy and write the test results to a CSV file",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     parser.add_argument(
         "strategy",
         metavar="CODE",
@@ -400,6 +482,14 @@ logging backtest progress at annual intervals:
         metavar="FREQ",
         help="log backtest progress at this interval (use a pandas offset alias, "
         "for example 'D' for daily, 'W' for weeky, 'M' for monthly, 'A' for annually)")
+    parser.add_argument(
+        "--params",
+        nargs="*",
+        type=dict_str,
+        metavar="PARAM:VALUE",
+        help="one or more strategy parameters (defined as module-level attributes "
+        "in the algo file) to modify on the fly before backtesting (pass as "
+        "'param:value')")
     parser.add_argument(
         "-o", "--output",
         metavar="FILENAME",
@@ -407,6 +497,110 @@ logging backtest progress at annual intervals:
         help="the location to write the output file (omit to write to stdout)")
     parser.set_defaults(func="quantrocket.zipline._cli_backtest")
 
+    examples = """
+Run a parameter scan for a Zipline strategy. The resulting CSV can be plotted with
+moonchart.ParamscanTearsheet.
+
+Examples:
+
+Run a parameter scan for a moving average strategy called dma:
+
+.. code-block:: bash
+
+    quantrocket zipline paramscan dma -b usstock-1min -f daily -s 2015-01-03 -e 2022-06-30 -p MAVG_WINDOW -v 20 50 100 -o dma_MAVG_WINDOW.csv
+    """
+    parser = _subparsers.add_parser(
+        "paramscan",
+        help="run a parameter scan for a Zipline strategy",
+        epilog=examples,
+        formatter_class=HelpFormatter)
+    parser.add_argument(
+        "strategy",
+        metavar="CODE",
+        help="the strategy to run (strategy filename without extension)")
+    parser.add_argument(
+        "-f", "--data-frequency",
+        choices=["daily", "d", "minute", "m"],
+        help="the data frequency to use. Possible choices: %(choices)s "
+        "(default is minute)")
+    parser.add_argument(
+        "--capital-base",
+        type=float,
+        metavar="FLOAT",
+        help="the starting capital for the simulation (default is 1e6 (1 million))")
+    parser.add_argument(
+        "-b", "--bundle",
+        metavar="CODE",
+        help="the data bundle to use for the simulation. If omitted, the default "
+        "bundle (if set) is used.")
+    parser.add_argument(
+        "-s", "--start-date",
+        metavar="YYYY-MM-DD",
+        help="the start date of the simulation (defaults to the bundle start date)")
+    parser.add_argument(
+        "-e", "--end-date",
+        metavar="YYYY-MM-DD",
+        help="the end date of the simulation (defaults to today)")
+    parser.add_argument(
+        "-p", "--param1",
+        metavar="PARAM",
+        type=str,
+        required=True,
+        help="the name of the parameter to test (a module-level attribute in the "
+        "algo file)")
+    parser.add_argument(
+        "-v", "--vals1",
+        type=list_or_int_or_float_or_str,
+        metavar="VALUE",
+        nargs="+",
+        required=True,
+        help="parameter values to test (values can be integers, floats, strings, 'True', "
+        "'False', 'None', or 'default' (to test current param value); for lists/tuples, "
+        "use comma-separated values)")
+    parser.add_argument(
+        "--param2",
+        metavar="PARAM",
+        type=str,
+        help="name of a second parameter to test (for 2-D parameter scans)")
+    parser.add_argument(
+        "--vals2",
+        type=list_or_int_or_float_or_str,
+        metavar="VALUE",
+        nargs="*",
+        help="values to test for parameter 2 (values can be integers, floats, strings, "
+        "'True', 'False', 'None', or 'default' (to test current param value); for "
+        "lists/tuples, use comma-separated values)")
+    parser.add_argument(
+        "--params",
+        nargs="*",
+        type=dict_str,
+        metavar="PARAM:VALUE",
+        help="one or more strategy parameters (defined as module-level attributes "
+        "in the algo file) to modify on the fly before running the parameter scan "
+        "(pass as 'param:value')")
+    parser.add_argument(
+        "-n", "--num-workers",
+        type=int,
+        metavar="INT",
+        help="the number of parallel workers to run. Running in parallel can speed "
+        "up the parameter scan if your system has adequate resources. Default "
+        "is 1, meaning no parallel processing.")
+    parser.add_argument(
+        "--progress",
+        metavar="FREQ",
+        help="log backtest progress at this interval (use a pandas offset alias, "
+        "for example 'D' for daily, 'W' for weeky, 'M' for monthly, 'A' for annually). "
+        "This parameter controls logging in the underlying backtests; a summary of scan "
+        "results will be logged regardless of this parameter. Using this parameter when "
+        "--num-workers is greater than 1 will result in messy and interleaved log output "
+        "and is not recommended.")
+    parser.add_argument(
+        "-o", "--output",
+        metavar="FILENAME",
+        dest="filepath_or_buffer",
+        help="the location to write the output file (omit to write to stdout)")
+    parser.set_defaults(func="quantrocket.zipline._cli_scan_parameters")
+
     examples = """
 Create a pyfolio PDF tear sheet from a Zipline backtest result.
 
@@ -414,18 +608,22 @@ Examples:
 
 Create a pyfolio tear sheet from a Zipline CSV results file:
 
+.. code-block:: bash
+
     quantrocket zipline tearsheet results.csv -o results.pdf
 
 Run a Zipline backtest and create a pyfolio tear sheet without saving
 the CSV file:
 
+.. code-block:: bash
+
     quantrocket zipline backtest dma -s 2010-04-01 -e 2016-02-01 | quantrocket zipline tearsheet -o dma.pdf
     """
     parser = _subparsers.add_parser(
         "tearsheet",
         help="create a pyfolio tear sheet from a Zipline backtest result",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     parser.add_argument(
         "infilepath_or_buffer",
         metavar="FILENAME",
@@ -447,13 +645,15 @@ Examples:
 
 Trade a strategy defined in momentum-pipeline.py:
 
+.. code-block:: bash
+
     quantrocket zipline trade momentum-pipeline --bundle my-bundle
     """
     parser = _subparsers.add_parser(
         "trade",
         help="trade a Zipline strategy",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     parser.add_argument(
         "strategy",
         metavar="CODE",
@@ -473,6 +673,13 @@ Trade a strategy defined in momentum-pipeline.py:
         choices=["daily", "d", "minute", "m"],
         help="the data frequency to use. Possible choices: %(choices)s "
         "(default is minute)")
+    parser.add_argument(
+        "--dry-run",
+        action="store_true",
+        help="write orders to file instead of sending them to the blotter. "
+        "Orders will be written to "
+        "/codeload/zipline/{strategy}.{account}.orders.{date}.csv. "
+        "If omitted, orders are sent to the blotter and not written to file.")
     parser.set_defaults(func="quantrocket.zipline._cli_trade")
 
     examples = """
@@ -482,13 +689,15 @@ Examples:
 
 List strategies:
 
+.. code-block:: bash
+
     quantrocket zipline active
     """
     parser = _subparsers.add_parser(
         "active",
         help="list actively trading Zipline strategies",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     parser.set_defaults(func="quantrocket.zipline._cli_list_active_strategies")
 
     examples = """
@@ -498,17 +707,21 @@ Examples:
 
 Cancel a single strategy:
 
+.. code-block:: bash
+
     quantrocket zipline cancel --strategies momentum-pipeline
 
 Cancel all strategies:
 
+.. code-block:: bash
+
     quantrocket zipline cancel --all
     """
     parser = _subparsers.add_parser(
         "cancel",
         help="cancel actively trading strategies",
         epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=HelpFormatter)
     parser.add_argument(
         "-s", "--strategies",
         nargs="*",
