@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# Copyright 2017 QuantRocket - All Rights Reserved
+# Copyright 2017-2022 QuantRocket - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,6 +14,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+__all__ = [
+    "FlightlogHandler",
+    "stream_logs",
+    "download_logfile",
+    "wait_for_message",
+    "get_timezone",
+    "set_timezone",
+    "get_papertrail_config",
+    "set_papertrail_config",
+]
+
 import logging, logging.handlers
 import socket
 import time
