@@ -1,4 +1,4 @@
-# Copyright 2017 QuantRocket - All Rights Reserved
+# Copyright 2017-2022 QuantRocket - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,7 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import six
 import os
 import sys
 import requests
@@ -23,6 +22,22 @@ from quantrocket.cli.utils.files import write_response_to_filepath_or_buffer
 from quantrocket.cli.utils.parse import dict_strs_to_dict, dict_to_dict_strs
 from quantrocket.exceptions import NoHistoricalData
 
+__all__ = [
+    "create_edi_db",
+    "create_ibkr_db",
+    "create_sharadar_db",
+    "create_usstock_db",
+    "create_custom_db",
+    "get_db_config",
+    "drop_db",
+    "list_databases",
+    "collect_history",
+    "get_history_queue",
+    "cancel_collections",
+    "wait_for_collections",
+    "download_history_file",
+]
+
 TMP_DIR = os.environ.get("QUANTROCKET_TMP_DIR", "/tmp")
 
 def create_edi_db(code, exchanges):
