@@ -1,4 +1,4 @@
-# Copyright 2019 QuantRocket - All Rights Reserved
+# Copyright 2017-2022 QuantRocket - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,6 +22,14 @@ from quantrocket.cli.utils.files import write_response_to_filepath_or_buffer
 from quantrocket.cli.utils.parse import dict_strs_to_dict, dict_to_dict_strs
 from quantrocket.utils.parse import _read_moonshot_or_pnl_csv
 
+__all__ = [
+    "backtest",
+    "read_moonshot_csv",
+    "scan_parameters",
+    "ml_walkforward",
+    "trade",
+]
+
 def backtest(strategies, start_date=None, end_date=None, segment=None, allocations=None,
              nlv=None, params=None, details=None, output="csv", filepath_or_buffer=None,
              no_cache=False):
@@ -178,12 +186,13 @@ def read_moonshot_csv(filepath_or_buffer):
 
 def scan_parameters(strategies, start_date=None, end_date=None, segment=None,
                     param1=None, vals1=None, param2=None, vals2=None,
-                    allocations=None, nlv=None, params=None, output="csv",
-                    filepath_or_buffer=None, no_cache=False):
+                    allocations=None, nlv=None, params=None, num_workers=None,
+                    output="csv", filepath_or_buffer=None, no_cache=False):
     """
     Run a parameter scan for one or more strategies.
 
-    By default returns a CSV of scan results but can also return a PDF tear sheet.
+    By default, returns a CSV of scan results which can be plotted with
+    `moonchart.ParamscanTearsheet`, but can also return a PDF tear sheet.
 
     Parameters
     ----------
@@ -227,8 +236,13 @@ def scan_parameters(strategies, start_date=None, end_date=None, segment=None,
         as {currency:nlv})
 
     params : dict of PARAM:VALUE, optional
-        one or more strategy params to set on the fly before backtesting
-        (pass as {param:value})
+        one or more strategy params to set on the fly before running the
+        parameter scan (pass as {param:value})
+
+    num_workers : int, optional
+        the number of parallel workers to run. Running in parallel can speed
+        up the parameter scan if your system has adequate resources. Default
+        is 1, meaning no parallel processing.
 
     output : str, required
         the output format (choices are csv or pdf)
@@ -248,12 +262,14 @@ def scan_parameters(strategies, start_date=None, end_date=None, segment=None,
     Examples
     --------
     Run a parameter scan for several different moving averages on a strategy
-    called trend-friend and return a CSV (which can be rendered with Moonchart):
+    called trend-friend, then view a tear sheet of the results:
 
+    >>> from moonchart import ParamscanTearsheet
     >>> scan_parameters("trend-friend",
                         param1="MAVG_WINDOW",
                         vals1=[20, 50, 100],
                         filepath_or_buffer="trend_friend_MAVG_WINDOW.csv")
+    >>> ParamscanTearsheet.from_csv("trend_friend_MAVG_WINDOW.csv")
 
     Run a 2-D parameter scan for multiple strategies and return a CSV:
 
@@ -263,6 +279,7 @@ def scan_parameters(strategies, start_date=None, end_date=None, segment=None,
                         param2="STD_WINDOW",
                         vals2=[20, 50, 100, 200],
                         filepath_or_buffer="strategies_MIN_STD_and_STD_WINDOW.csv")
+    >>> ParamscanTearsheet.from_csv("strategies_MIN_STD_and_STD_WINDOW.csv")
 
     Run a parameter scan in 1-year segments to reduce memory usage:
 
@@ -302,6 +319,8 @@ def scan_parameters(strategies, start_date=None, end_date=None, segment=None,
         _params["nlv"] = dict_to_dict_strs(nlv)
     if params:
         _params["params"] = dict_to_dict_strs(params)
+    if num_workers:
+        _params["num_workers"] = num_workers
     if no_cache:
         _params["no_cache"] = no_cache
 
