@@ -1,4 +1,4 @@
-# Copyright 2019 QuantRocket - All Rights Reserved
+# Copyright 2017-2022 QuantRocket - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -33,6 +33,11 @@ from quantrocket.zipline import (
     get_bundle_config,
     download_bundle_file)
 
+__all__ = [
+    "get_prices",
+    "get_prices_reindexed_like",
+]
+
 TMP_DIR = os.environ.get("QUANTROCKET_TMP_DIR", tempfile.gettempdir())
 
 def get_prices(codes, start_date=None, end_date=None,
@@ -680,6 +685,7 @@ def get_prices_reindexed_like(reindex_like, codes, fields=None,
         start_date=start_date,
         end_date=end_date,
         timezone=timezone,
+        infer_timezone=infer_timezone,
         times=times,
         cont_fut=cont_fut,
         data_frequency=data_frequency)
