@@ -1,4 +1,4 @@
-# Copyright 2019 QuantRocket - All Rights Reserved
+# Copyright 2017-2022 QuantRocket - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,6 +22,21 @@ from quantrocket.exceptions import NoRealtimeData, ParameterError
 from quantrocket.cli.utils.output import json_to_cli
 from quantrocket.cli.utils.parse import dict_strs_to_dict, dict_to_dict_strs
 
+__all__ = [
+    "create_ibkr_tick_db",
+    "create_polygon_tick_db",
+    "create_alpaca_tick_db",
+    "create_agg_db",
+    "get_db_config",
+    "drop_db",
+    "drop_ticks",
+    "list_databases",
+    "collect_market_data",
+    "get_active_collections",
+    "cancel_market_data",
+    "download_market_data_file",
+]
+
 def create_ibkr_tick_db(code, universes=None, sids=None, fields=None,
                         primary_exchange=False):
     """
@@ -668,7 +683,7 @@ def _cli_download_market_data_file(*args, **kwargs):
 
 def _cli_stream_market_data(sids, exclude_sids, fields):
 
-    url = houston.base_url + "/realtime/stream"
+    url = houston.base_url.replace("http", "ws") + "/realtime/stream"
 
     params = {}
 
