@@ -1,4 +1,4 @@
-# Copyright 2017 QuantRocket - All Rights Reserved
+# Copyright 2017-2022 QuantRocket - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,11 +18,30 @@ import requests
 from quantrocket.houston import houston
 from quantrocket.exceptions import NoHistoricalData
 from quantrocket.cli.utils.output import json_to_cli
-from quantrocket.cli.utils.stream import to_bytes
 from quantrocket.cli.utils.files import write_response_to_filepath_or_buffer
 from quantrocket.cli.utils.parse import dict_strs_to_dict, dict_to_dict_strs
 from quantrocket.utils.warn import deprecated_replaced_by
 
+__all__ = [
+    "create_usstock_bundle",
+    "create_sharadar_bundle",
+    "create_bundle_from_db",
+    "ingest_bundle",
+    "list_bundles",
+    "get_bundle_config",
+    "drop_bundle",
+    "get_default_bundle",
+    "set_default_bundle",
+    "download_bundle_file",
+    "backtest",
+    "scan_parameters",
+    "create_tearsheet",
+    "trade",
+    "list_active_strategies",
+    "cancel_strategies",
+    "ZiplineBacktestResult",
+]
+
 def create_usstock_bundle(code, sids=None, universes=None, free=False, data_frequency=None):
     """
     Create a Zipline bundle for US stocks.
@@ -91,6 +110,59 @@ def create_usstock_bundle(code, sids=None, universes=None, free=False, data_freq
 def _cli_create_usstock_bundle(*args, **kwargs):
     return json_to_cli(create_usstock_bundle, *args, **kwargs)
 
+def create_sharadar_bundle(code, sec_types=None, free=False):
+    """
+    Create a Zipline bundle of daily data for Sharadar stocks and/or ETFs.
+
+    This function defines the bundle parameters but does not ingest the actual
+    data. To ingest the data, see `ingest_bundle`.
+
+    Parameters
+    ----------
+    code : str, required
+        the code to assign to the bundle (lowercase alphanumerics and hyphens only)
+
+    sec_types : list of str, optional
+        limit to these security types. Possible choices: STK, ETF. Default is to
+        include both stocks and ETFs.
+
+    free : bool
+        limit to free sample data
+
+    Returns
+    -------
+    dict
+        status message
+
+    Examples
+    --------
+    Create a bundle for all Sharadar stocks and ETFs:
+
+    >>> create_sharadar_bundle("sharadar-1d")
+
+    Create a bundle for ETFs only:
+
+    >>> create_sharadar_bundle("sharadar-etf-1d", sec_types="ETF")
+
+    Create a bundle of free sample data:
+
+    >>> create_sharadar_bundle("sharadar-free-1d", free=True)
+    """
+    params = {}
+    params["ingest_type"] = "sharadar"
+    if sec_types:
+        params["sec_types"] = sec_types
+    if free:
+        params["free"] = free
+
+    response = houston.put("/zipline/bundles/{}".format(code), params=params)
+
+    houston.raise_for_status_with_json(response)
+    return response.json()
+
+def _cli_create_sharadar_bundle(*args, **kwargs):
+    return json_to_cli(create_sharadar_bundle, *args, **kwargs)
+
 def create_bundle_from_db(code, from_db, calendar,
                          start_date=None, end_date=None,
                          universes=None, sids=None,
@@ -110,8 +182,11 @@ def create_bundle_from_db(code, from_db, calendar,
     code : str, required
         the code to assign to the bundle (lowercase alphanumerics and hyphens only)
 
-    from_db : str, required
-        the code of a history database or real-time aggregate database to ingest
+    from_db : str or list of str, required
+        the code(s) of one or more history databases or real-time aggregate databases
+        to ingest. If multiple databases are specified, they must have the same bar
+        size and the same fields. If a security is present in multiple databases, the
+        first database's values will be used.
 
     calendar : str, required
         the name of the calendar to use with this bundle (provide '?' or
@@ -477,7 +552,8 @@ def download_minute_file(*args, **kwargs):
     return download_bundle_file(*args, **kwargs)
 
 def backtest(strategy, data_frequency=None, capital_base=None, bundle=None,
-             start_date=None, end_date=None, progress=None, filepath_or_buffer=None):
+             start_date=None, end_date=None, progress=None, params=None,
+             filepath_or_buffer=None):
     """
     Backtest a Zipline strategy and write the test results to a CSV file.
 
@@ -512,6 +588,11 @@ def backtest(strategy, data_frequency=None, capital_base=None, bundle=None,
         for example "D" for daily, "W" for weeky, "M" for monthly,
         "A" for annually)
 
+    params : dict of PARAM:VALUE, optional
+        one or more strategy parameters (defined as module-level attributes
+        in the algo file) to modify on the fly before backtesting (pass as
+        {param:value}).
+
     filepath_or_buffer : str, optional
         the location to write the output file (omit to write to stdout)
 
@@ -534,21 +615,23 @@ def backtest(strategy, data_frequency=None, capital_base=None, bundle=None,
     >>> import pyfolio as pf
     >>> pf.from_zipline_csv("momentum_pipeline_results.csv")
     """
-    params = {}
+    _params = {}
     if data_frequency:
-        params["data_frequency"] = data_frequency
+        _params["data_frequency"] = data_frequency
     if capital_base:
-        params["capital_base"] = capital_base
+        _params["capital_base"] = capital_base
     if bundle:
-        params["bundle"] = bundle
+        _params["bundle"] = bundle
     if start_date:
-        params["start_date"] = start_date
+        _params["start_date"] = start_date
     if end_date:
-        params["end_date"] = end_date
+        _params["end_date"] = end_date
+    if params:
+        _params["params"] = dict_to_dict_strs(params)
     if progress:
-        params["progress"] = progress
+        _params["progress"] = progress
 
-    response = houston.post("/zipline/backtests/{0}".format(strategy), params=params, timeout=60*60*96)
+    response = houston.post("/zipline/backtests/{0}".format(strategy), params=_params, timeout=60*60*96)
 
     houston.raise_for_status_with_json(response)
 
@@ -556,8 +639,157 @@ def backtest(strategy, data_frequency=None, capital_base=None, bundle=None,
     write_response_to_filepath_or_buffer(filepath_or_buffer, response)
 
 def _cli_backtest(*args, **kwargs):
+    params = kwargs.get("params", None)
+    if params:
+        kwargs["params"] = dict_strs_to_dict(*params)
     return json_to_cli(backtest, *args, **kwargs)
 
+def scan_parameters(strategy,  data_frequency=None, capital_base=None, bundle=None,
+                    start_date=None, end_date=None,
+                    param1=None, vals1=None, param2=None, vals2=None,
+                    progress=None, params=None, num_workers=None,
+                    filepath_or_buffer=None):
+    """
+    Run a parameter scan for a Zipline strategy.
+
+    Returns a CSV of scan results which can be plotted with
+    `moonchart.ParamscanTearsheet`.
+
+    Parameters
+    ----------
+    strategy : str, required
+        the strategy to run (strategy filename without extension)
+
+    data_frequency : str, optional
+        the data frequency of the simulation. Possible choices: daily, minute
+        (or aliases d, m). Default is minute.
+
+    capital_base : float, optional
+        the starting capital for the simulation (default is 1e6 (1 million))
+
+    bundle : str, optional
+        the data bundle to use for the simulation. If omitted, the default bundle (if set)
+        is used.
+
+    start_date : str (YYYY-MM-DD), optional
+        the start date of the simulation (defaults to the bundle start date)
+
+    end_date : str (YYYY-MM-DD), optional
+        the end date of the simulation (defaults to today)
+
+    param1 : str, required
+        the name of the parameter to test (a module-level attribute
+        in the algo file)
+
+    vals1 : list of int/float/str/tuple, required
+        parameter values to test (values can be ints, floats, strings, False,
+        True, None, 'default' (to test current param value), or lists of
+        ints/floats/strings)
+
+    param2 : str, optional
+        name of a second parameter to test (for 2-D parameter scans)
+
+    vals2 : list of int/float/str/tuple, optional
+        values to test for parameter 2 (values can be ints, floats, strings,
+        False, True, None, 'default' (to test current param value), or lists
+        of ints/floats/strings)
+
+    params : dict of PARAM:VALUE, optional
+        one or more strategy parameters (defined as module-level attributes
+        in the algo file) to modify on the fly before running the parameter
+        scan (pass as {param:value}).
+
+    num_workers : int, optional
+        the number of parallel workers to run. Running in parallel can speed
+        up the parameter scan if your system has adequate resources. Default
+        is 1, meaning no parallel processing.
+
+    progress : str, optional
+        log backtest progress at this interval (use a pandas offset alias,
+        for example "D" for daily, "W" for weeky, "M" for monthly,
+        "A" for annually). This parameter controls logging in the underlying
+        backtests; a summary of scan results will be logged regardless of this
+        parameter. Using this parameter when num_workers is greater than 1 will
+        result in messy and interleaved log output and is not recommended.
+
+    filepath_or_buffer : str, optional
+        the location to write the output file (omit to write to stdout)
+
+    Returns
+    -------
+    None
+
+    Examples
+    --------
+    Run a parameter scan for a moving average strategy called dma, then
+    view a tear sheet of the results:
+
+    >>> from moonchart import ParamscanTearsheet
+    >>> scan_parameters("dma",
+                        bundle="usstock-1min",
+                        data_frequency="daily",
+                        start_date="2015-01-03",
+                        end_date="2022-06-30",
+                        param1="MAVG_WINDOW",
+                        vals1=[20, 50, 100],
+                        filepath_or_buffer="dma_MAVG_WINDOW.csv")
+    >>> ParamscanTearsheet.from_csv("dma_MAVG_WINDOW.csv")
+
+    Run a 2-D parameter scan testing combinations of values for a long and
+    short moving average, using 3 parallel worker processes:
+
+    >>> scan_parameters("dma",
+                        bundle="usstock-1min",
+                        data_frequency="daily",
+                        start_date="2015-01-03",
+                        end_date="2022-06-30",
+                        param1="LONG_MAVG_WINDOW",
+                        vals1=[100, 200],
+                        param2="SHORT_MAVG_WINDOW",
+                        vals2=[20, 50],
+                        num_workers=3,
+                        filepath_or_buffer="dma_LONG_MAVG_WINDOW_and_SHORT_MAVG_WINDOW.csv")
+    >>> ParamscanTearsheet.from_csv("dma_LONG_MAVG_WINDOW_and_SHORT_MAVG_WINDOW.csv")
+    """
+    _params = {}
+    if data_frequency:
+        _params["data_frequency"] = data_frequency
+    if capital_base:
+        _params["capital_base"] = capital_base
+    if bundle:
+        _params["bundle"] = bundle
+    if start_date:
+        _params["start_date"] = start_date
+    if end_date:
+        _params["end_date"] = end_date
+    if progress:
+        _params["progress"] = progress
+    if param1:
+        _params["param1"] = param1
+    if vals1:
+        _params["vals1"] = [str(v) for v in vals1]
+    if param2:
+        _params["param2"] = param2
+    if vals2:
+        _params["vals2"] = [str(v) for v in vals2]
+    if params:
+        _params["params"] = dict_to_dict_strs(params)
+    if num_workers:
+        _params["num_workers"] = num_workers
+
+    response = houston.post("/zipline/paramscans/{0}".format(strategy), params=_params, timeout=60*60*96)
+
+    houston.raise_for_status_with_json(response)
+
+    filepath_or_buffer = filepath_or_buffer or sys.stdout
+    write_response_to_filepath_or_buffer(filepath_or_buffer, response)
+
+def _cli_scan_parameters(*args, **kwargs):
+    params = kwargs.get("params", None)
+    if params:
+        kwargs["params"] = dict_strs_to_dict(*params)
+    return json_to_cli(scan_parameters, *args, **kwargs)
+
 def create_tearsheet(infilepath_or_buffer, outfilepath_or_buffer=None):
     """
     Create a pyfolio PDF tear sheet from a Zipline backtest result.
@@ -599,7 +831,7 @@ def create_tearsheet(infilepath_or_buffer, outfilepath_or_buffer=None):
 def _cli_create_tearsheet(*args, **kwargs):
     return json_to_cli(create_tearsheet, *args, **kwargs)
 
-def trade(strategy, bundle=None, account=None, data_frequency=None):
+def trade(strategy, bundle=None, account=None, data_frequency=None, dry_run=False):
     """
     Trade a Zipline strategy.
 
@@ -621,6 +853,13 @@ def trade(strategy, bundle=None, account=None, data_frequency=None):
         the data frequency to use. Possible choices: daily, minute
         (or aliases d, m). Default is minute.
 
+    dry_run : bool
+        write orders to file instead of sending them to the blotter.
+        Orders will be written to
+        /codeload/zipline/{strategy}.{account}.orders.{date}.csv.
+        Default is False, meaning orders will be sent to the blotter
+        and not written to file.
+
     Returns
     -------
     None
@@ -638,6 +877,8 @@ def trade(strategy, bundle=None, account=None, data_frequency=None):
         params["account"] = account
     if data_frequency:
         params["data_frequency"] = data_frequency
+    if dry_run:
+        params["dry_run"] = dry_run
 
     response = houston.post("/zipline/trade/{0}".format(strategy), params=params)
 
@@ -721,11 +962,11 @@ class ZiplineBacktestResult(object):
     Run a Zipline backtest and parse the CSV results:
 
     >>> f = io.StringIO()
-    >>> run_algorithm("momentum_pipeline.py",
-              bundle="etf-sampler-1d",
-              start="2015-02-04",
-              end="2015-12-31",
-              filepath_or_buffer=f)
+    >>> backtest("momentum_pipeline.py",
+                 bundle="etf-sampler-1d",
+                 start="2015-02-04",
+                 end="2015-12-31",
+                 filepath_or_buffer=f)
     >>> zipline_result = ZiplineBacktestResult.from_csv(f)
 
     The ZiplineBacktestResult object contains returns, positions, transactions,
@@ -767,7 +1008,8 @@ class ZiplineBacktestResult(object):
         results = pd.read_csv(
             filepath_or_buffer,
             parse_dates=["date"],
-            index_col=["dataframe", "index", "date", "column"])["value"]
+            index_col=["dataframe", "index", "date", "column"],
+            low_memory=False)["value"]
 
         # Extract returns
         returns = results.loc["returns"].unstack()
